@@ -124,6 +124,7 @@ void EventArchiver::run(const Akonadi::ETMCalendar::Ptr &calendar,
         if (withGUI && errorIfNone) {
             KMessageBox::information(widget,
                                      i18n("There are no items before %1", QLocale::system().toString(limitDate, QLocale::ShortFormat)),
+                                     i18nc("@title:window", "Archive"),
                                      QStringLiteral("ArchiverNoIncidences"));
         }
         return;
@@ -155,7 +156,7 @@ void EventArchiver::deleteIncidences(Akonadi::IncidenceChanger *changer, QDate l
                                                                        "The following items will be deleted:",
                                                                        QLocale::system().toString(limitDate, QLocale::ShortFormat)),
                                                                   incidenceStrs,
-                                                                  i18n("Delete Old Items"),
+                                                                  i18nc("@title:window", "Delete Old Items"),
                                                                   KStandardGuiItem::del());
         if (result != KMessageBox::Continue) {
             return;
@@ -233,7 +234,7 @@ void EventArchiver::archiveIncidences(const Akonadi::ETMCalendar::Ptr &calendar,
     if (archiveURL.isLocalFile()) {
         fileExists = QFile::exists(archiveURL.toLocalFile());
     } else {
-        auto job = KIO::statDetails(archiveURL, KIO::StatJob::SourceSide, KIO::StatBasic);
+        auto job = KIO::stat(archiveURL, KIO::StatJob::SourceSide, KIO::StatBasic);
 
         KJobWidgets::setWindow(job, widget);
         fileExists = job->exec();
@@ -323,3 +324,5 @@ bool EventArchiver::isSubTreeComplete(const Akonadi::ETMCalendar::Ptr &calendar,
 
     return true;
 }
+
+#include "moc_eventarchiver.cpp"
