@@ -3,7 +3,7 @@
   SPDX-FileCopyrightText: 2003 Reinhold Kainhofer <reinhold@kainhofer.com>
   SPDX-FileCopyrightText: 2003 Cornelius Schumacher <schumacher@kde.org>
   SPDX-FileCopyrightText: 2008 Ron Goodheart <rong.dev@gmail.com>
-  SPDX-FileCopyrightText: 2010-2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2010-2024 Laurent Montel <montel@kde.org>
   SPDX-FileCopyrightText: 2012-2013 Allen Winter <winter@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
@@ -1731,10 +1731,6 @@ void CalPrintTodos::print(QPainter &p, int width, int height)
     // Print to-dos
     int count = 0;
     for (const KCalendarCore::Todo::Ptr &todo : std::as_const(todoList)) {
-        if ((mExcludeConfidential && todo->secrecy() == KCalendarCore::Incidence::SecrecyConfidential)
-            || (mExcludePrivate && todo->secrecy() == KCalendarCore::Incidence::SecrecyPrivate)) {
-            continue;
-        }
         // Skip sub-to-dos. They will be printed recursively in drawTodo()
         if (todo->relatedTo().isEmpty()) { // review(AKONADI_PORT)
             count++;
