@@ -63,7 +63,7 @@ void CalPrintJournal::doLoadConfig()
 {
     CalPrintPluginBase::doLoadConfig();
     if (mConfig) {
-        KConfigGroup config(mConfig, "Journalprint");
+        KConfigGroup config(mConfig, QStringLiteral("Journalprint"));
         mUseDateRange = config.readEntry("JournalsInRange", false);
     }
     setSettingsWidget();
@@ -75,7 +75,7 @@ void CalPrintJournal::doSaveConfig()
 
     readSettingsWidget();
     if (mConfig) {
-        KConfigGroup config(mConfig, "Journalprint");
+        KConfigGroup config(mConfig, QStringLiteral("Journalprint"));
         config.writeEntry("JournalsInRange", mUseDateRange);
     }
     CalPrintPluginBase::doSaveConfig();
@@ -135,7 +135,8 @@ void CalPrintJournal::drawJournal(const KCalendarCore::Journal::Ptr &journal, QP
 
 void CalPrintJournal::print(QPainter &p, int width, int height)
 {
-    int x = 0, y = 0;
+    int x = 0;
+    int y = 0;
     KCalendarCore::Journal::List journals(mCalendar->journals(KCalendarCore::JournalSortDate, KCalendarCore::SortDirectionAscending));
     if (mUseDateRange) {
         const KCalendarCore::Journal::List allJournals = journals;
@@ -157,8 +158,7 @@ void CalPrintJournal::print(QPainter &p, int width, int height)
 
     for (const KCalendarCore::Journal::Ptr &j : std::as_const(journals)) {
         Q_ASSERT(j);
-        if (j
-            && (!mExcludeConfidential || j->secrecy() != KCalendarCore::Incidence::SecrecyConfidential)
+        if (j && (!mExcludeConfidential || j->secrecy() != KCalendarCore::Incidence::SecrecyConfidential)
             && (!mExcludePrivate || j->secrecy() != KCalendarCore::Incidence::SecrecyPrivate)) {
             drawJournal(j, p, x, y, width, height);
         }
