@@ -64,7 +64,7 @@ void CalPrintYear::doLoadConfig()
 {
     CalPrintPluginBase::doLoadConfig();
     if (mConfig) {
-        KConfigGroup config(mConfig, "Yearprint");
+        KConfigGroup config(mConfig, QStringLiteral("Yearprint"));
         mYear = config.readEntry("Year", QDate::currentDate().year());
         mPages = config.readEntry("Pages", 1);
         mSubDaysEvents = config.readEntry("ShowSubDayEventsAs", static_cast<int>(TimeBoxes));
@@ -79,7 +79,7 @@ void CalPrintYear::doSaveConfig()
 
     readSettingsWidget();
     if (mConfig) {
-        KConfigGroup config(mConfig, "Yearprint");
+        KConfigGroup config(mConfig, QStringLiteral("Yearprint"));
         config.writeEntry("Year", mYear);
         config.writeEntry("Pages", mPages);
         config.writeEntry("Pages", mPages);
@@ -137,7 +137,7 @@ void CalPrintYear::print(QPainter &p, int width, int height)
         end = end.addDays(-1);
         QString stdate = locale.toString(start, QLocale::ShortFormat);
         QString endate = locale.toString(end, QLocale::ShortFormat);
-        QString title =i18nc("date from-to", "%1\u2013%2", stdate, endate);
+        QString title = i18nc("date from-to", "%1\u2013%2", stdate, endate);
         drawHeader(p, title, start.addMonths(-1), start.addMonths(monthsPerPage), headerBox);
 
         QRect monthesBox(headerBox);
