@@ -6,6 +6,7 @@
 */
 
 #include "urihandler.h"
+
 #include "calendarsupport_debug.h"
 
 #include <KIO/ApplicationLauncherJob>
@@ -17,7 +18,7 @@
 #include <QUrlQuery>
 
 using namespace CalendarSupport;
-
+using namespace Qt::Literals::StringLiterals;
 namespace
 {
 bool startService(const QString &desktopFileName, const QString &uri)
@@ -59,27 +60,27 @@ bool UriHandler::process(const QString &uri)
 {
     qCDebug(CALENDARSUPPORT_LOG) << uri;
 
-    if (uri.startsWith(QLatin1String("kmail:"))) {
+    if (uri.startsWith("kmail:"_L1)) {
         // extract 'number' from 'kmail:<number>/<id>'
         const int start = uri.indexOf(QLatin1Char(':')) + 1;
         const int end = uri.indexOf(QLatin1Char('/'), start);
         const QString serialNumberStr = uri.mid(start, start - end);
         return startKMail(QStringLiteral("akonadi://?item=%1").arg(serialNumberStr));
-    } else if (uri.startsWith(QLatin1String("mailto:"))) {
+    } else if (uri.startsWith("mailto:"_L1)) {
         return QDesktopServices::openUrl(QUrl(uri));
-    } else if (uri.startsWith(QLatin1String("uid:"))) {
+    } else if (uri.startsWith("uid:"_L1)) {
         const QString uid = uri.mid(4);
         return startKAddressbook(QStringLiteral("akonadi://?item=%1").arg(uid));
-    } else if (uri.startsWith(QLatin1String("urn:x-ical"))) {
+    } else if (uri.startsWith("urn:x-ical"_L1)) {
         const QString uid = QUrl::fromPercentEncoding(uri.toLatin1()).mid(11);
         return startKOrganizer(QStringLiteral("akonadi://?item=%1").arg(uid));
-    } else if (uri.startsWith(QLatin1String("akonadi:"))) {
+    } else if (uri.startsWith("akonadi:"_L1)) {
         const QString mimeType = QUrlQuery(QUrl(uri)).queryItemValue(QStringLiteral("type")).toLower();
-        if (mimeType == QLatin1String("message/rfc822")) {
+        if (mimeType == "message/rfc822"_L1) {
             return startKMail(uri);
-        } else if (mimeType == QLatin1String("text/calendar")) {
+        } else if (mimeType == "text/calendar"_L1) {
             return startKOrganizer(uri);
-        } else if (mimeType == QLatin1String("text/directory")) {
+        } else if (mimeType == "text/directory"_L1) {
             return startKAddressbook(uri);
         }
     } else { // no special URI, let KDE handle it
